# Usage

napari leverages the power of Python to enable fast and interactive browsing,
annotation and analysis of large multi-dimensional images.

::::{grid}
:::{grid-item-card} napari quick start
:link: napari-quick-start
:link-type: ref

If you are new to napari, check out the **napari quickstart tutorial**.
:::

:::{grid-item-card} Tutorials
:link: napari-tutorials
:link-type: ref

The tutorials are meant to help you understand how to use
napari, as well as learn about its features and use cases.
:::
::::

::::{grid}
:::{grid-item-card} Using layers
:link: using-layers
:link-type: ref

**Layers** are the viewable objects that can be added to a viewer.
Check these guides on how to use the layers currently supported by napari.
:::

:::{grid-item-card} How-to guides
:link: how-tos
:link-type: ref

Guides on completing specific tasks with napari.
::::

::::{grid}
:::{grid-item-card} In-depth explanations
:link: explanations
:link-type: ref

These guides are aimed at those looking for best practices and more
information on how napari works internally.
:::

:::{grid-item-card} Gallery
:link: gallery
:link-type: ref

Examples of napari usage, to be downloaded as Python scripts or Jupyter notebooks.
:::

:::{grid-item-card} napari workshops
:link: napari-workshops
:link-type: ref

A list of information and materials for workshops given about napari.
:::
::::
